@@ -1,8 +1,7 @@
 import contextlib
 import contextvars
 import dataclasses
-from collections.abc import Iterator
-from typing import Optional, Union, cast
+from typing import Iterator, Optional, Union, cast
 
 from .deadline import Deadline
 from .priority import Priority
