@@ -1,9 +1,7 @@
-import dataclasses
 import datetime
 from typing import Optional
 
 
-@dataclasses.dataclass(init=False, frozen=True, order=True)
 class Deadline:
     @staticmethod
     def from_timeout(seconds: float) -> "Deadline":
@@ -26,7 +24,7 @@ class Deadline:
         if deadline_at.tzinfo is not None:
             raise RuntimeError("Deadline should not be zone aware")
 
-        object.__setattr__(self, "deadline_at", deadline_at)
+        self.deadline_at = deadline_at
 
     @property
     def timeout(self) -> float:
